==> aegisub_2.1.9.orig.tar.gz: aegisub-2.1.9/src/dialog_jumpto.h <==
// Copyright (c) 2005, Rodrigo Braz Monteiro
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of the Aegisub Group nor the names of its contributors
//     may be used to endorse or promote products derived from this software
//     without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//
// -----------------------------------------------------------------------------
//
// AEGISUB
//
// Website: http://aegisub.cellosoft.com
// Contact: mailto:zeratul@cellosoft.com
//


#ifndef DIALOG_JUMPTO_H
#define DIALOG_JUMPTO_H


///////////
// Headers
#include <wx/wxprec.h>
#include "ass_time.h"
#include "timeedit_ctrl.h"


/////////
// Class
class DialogJumpTo : public wxDialog {
private:
	bool ready;
	long jumpframe;
	AssTime jumptime;

	TimeEdit *JumpTime;
	wxTextCtrl *JumpFrame;

	void OnKey(wxCommandEvent &event);
	void OnCloseButton(wxCommandEvent &event);
	void OnOK(wxCommandEvent &event);
	void OnEditTime(wxCommandEvent &event);
	void OnEditFrame(wxCommandEvent &event);
	void OnClose(bool ok);

public:
	DialogJumpTo (wxWindow *parent);


	DECLARE_EVENT_TABLE()
};

#endif

==> aegisub_3.1.2.orig.tar.gz: aegisub-3.1.2/src/dialog_jumpto.h <==
// Copyright (c) 2005, Rodrigo Braz Monteiro
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of the Aegisub Group nor the names of its contributors
//     may be used to endorse or promote products derived from this software
//     without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//
// Aegisub Project http://www.aegisub.org/

/// @file dialog_jumpto.h
/// @see dialog_jumpto.cpp
/// @ingroup secondary_ui
///

#include <wx/dialog.h>

namespace agi { struct Context; }
class TimeEdit;
class wxTextCtrl;

class DialogJumpTo : public wxDialog {
	agi::Context *c;       ///< Project context
	long jumpframe;        ///< Target frame to jump to
	TimeEdit *JumpTime;    ///< Target time edit control
	wxTextCtrl *JumpFrame; ///< Target frame edit control

	/// Enter/OK button handler
	void OnOK(wxCommandEvent &event);
	/// Update target frame on target time changed
	void OnEditTime(wxCommandEvent &event);
	/// Update target time on target frame changed
	void OnEditFrame(wxCommandEvent &event);
	/// Dialog initializer to set default focus and selection
	void OnInitDialog(wxInitDialogEvent&);

public:
	/// Constructor
	/// @param c Project context
	DialogJumpTo(agi::Context *c);
};
